.. _Python: https://www.python.org/
.. _click: https://palletsprojects.com/p/click/
.. _colorlog: https://github.com/borntyping/python-colorlog
.. _tomli: https://github.com/hukkin/tomli

================
Project composer
================

A convenient system to structure and compose applications from a modular project.

Basically, you give it a project manifest that will be used to organize your various
project parts. Parts can be classes, text files or you can implement another part
kind.


Dependencies
************

* `Python`_>=3.8;
* `click`_ >=8.0;
* `colorlog`_;
* `tomli`_;


Links
*****

* Read the documentation on `Read the docs <https://project-composer.readthedocs.io/>`_;
* Download its `PyPi package <https://pypi.python.org/pypi/project-composer>`_;
* Clone it on its `Github repository <https://github.com/sveetch/project-composer>`_;
